# vim: set ts=4 sw=4 et:
# Copyright (c) 2002-2012 Manfred Tremmel <Manfred.Tremmel@iiv.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via packman@links2linux.de

%define veronly 0.3
%define state   beta15

Summary:        Hard disk temperature tool
Summary(de):    Festplatten Temperatur-Ausleseprogramm
Name:           hddtemp
Version:        0.3_beta15
Release:        14.40
License:        GPL-2.0+
Group:          System/Monitoring
URL:            http://www.guzu.net/linux/hddtemp.php

Source0:        hddtemp-0.3-beta15.tar.bz2
Source1:        hddtemp.db
Source2:        hddtemp.init
Source3:        hddtemp.sysconfig

Patch0:         hddtemp-db.patch
Patch1:         hddtemp_0.3-beta15-33.diff.bz2
Patch2:         hddtemp-0.3-beta15-sata-sense.patch
Vendor:         Packman
BuildRoot:      %{_tmppath}/%{name}-%{version}-buildroot
BuildRequires:  net-tools
BuildRequires:  perl
BuildRequires:  gettext
BuildRequires:  gawk
BuildRequires:  gcc
BuildRequires:  syslogd

%description
hddtemp is tool that gives you the temperature of your hard drive by
reading S.M.A.R.T. information.

%description -l de
htddtemp ist ein Tool zum auslesen der Festplattentemperatur aus den
S.M.A.R.T Informationenen.



%prep
%setup -q -n %{name}-%{veronly}-%{state}

cp -p %{SOURCE1} ./hddtemp.db
%patch0 -p0
%patch1 -p1
%patch2 -p1
sed -i -e s/Celius/Celsius/g src/hddtemp.c po/*.po*
sed -i -e 's|/etc/hddtemp.db|/usr/share/misc/hddtemp.db|' doc/hddtemp.8


chmod -x contribs/analyze/*
rm COPYING ; cp -p GPL-2 COPYING


%build
CFLAGS="%{optflags} -D_GNU_SOURCE" \
%configure
%{__make} %{?_smp_flags}

%install
%makeinstall
%{__mkdir_p} %{buildroot}%{_sysconfdir}/init.d
%{__mkdir_p} %{buildroot}%{_sysconfdir}/default
%{__mkdir_p} %{buildroot}%{_datadir}/misc/
%{__mkdir_p} %{buildroot}/var/adm/fillup-templates
%{__install} -m 0644 hddtemp.db %{buildroot}%{_datadir}/misc/
%{__mkdir_p} %{buildroot}/etc/
pushd %{buildroot}/etc/
%{__ln_s} ..%{_datadir}/misc/hddtemp.db ./hddtemp.db
popd
%{__install} -m 0755 %{SOURCE2} %{buildroot}%{_sysconfdir}/init.d/%{name}
%{__install} -m 0644 %{SOURCE3} %{buildroot}/var/adm/fillup-templates/sysconfig.%{name}
pushd %{buildroot}%{_sbindir}
%{__ln_s} ../..%{_sysconfdir}/init.d/%{name} rc%{name}
#%{__chmod} +s hddtemp
popd

%find_lang "%{name}"

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%post
if [ ! -f /etc/bash.bashrc.local ] ; then
    echo PATH=\$PATH:/usr/sbin >> /etc/bash.bashrc.local
else
    CAT=`cat /etc/bash.bashrc.local | grep /usr/sbin`
    if [ "$CAT" != "PATH=\$PATH:/usr/sbin" ] ; then
    	echo PATH=\$PATH:/usr/sbin >> /etc/bash.bashrc.local
    fi
fi
# Migrate %{_sysconfdir}/default/hddtemp to sysconfig (<=11.0,>=10.2,upstream)
#BEGIN hddtemp_opts_migrate
# generated by genopts
function optarg_parse()
{
    OPTARG_INTERVAL=false
    OPTARG_LOGFACILITY=false
    until [ $# -eq 0 ]
    do
    case "$1" in
    --interval )
        shift
        OPTARG_INTERVAL=true
        OPTVAL_INTERVAL="$1"
        ;;
    --interval=* )
        OPTARG_INTERVAL=true
        OPTVAL_INTERVAL="${1#--interval=}"
        ;;
    --logfacility )
        shift
        OPTARG_LOGFACILITY=true
        OPTVAL_LOGFACILITY="$1"
        ;;
    --logfacility=* )
        OPTARG_LOGFACILITY=true
        OPTVAL_LOGFACILITY="${1#--logfacility=}"
        ;;
    -* )
        OPTTMP="${1:1}"
        until [[ -z "$OPTTMP" ]]
        do
    	case "${OPTTMP:0:1}" in
    	i )
    	    OPTARG_INTERVAL=true
    	    OPTVAL_INTERVAL="${OPTTMP:1}"
    	    if [[ -z "$OPTVAL_INTERVAL" ]]
    	    then
    		shift
    		OPTVAL_INTERVAL="$1"
    	    else
    		break
    	    fi
    	    ;;
    	l )
    	    OPTARG_LOGFACILITY=true
    	    OPTVAL_LOGFACILITY="${OPTTMP:1}"
    	    if [[ -z "$OPTVAL_LOGFACILITY" ]]
    	    then
    		shift
    		OPTVAL_LOGFACILITY="$1"
    	    else
    		break
    	    fi
    	    ;;
    	esac
        OPTTMP="${OPTTMP:1}"
        done
        ;;
    * )
        ARGV=("${ARGV[@]}" "$1")
        ;;
    esac
    shift
    done
}
if test -f %{_sysconfdir}/default/hddtemp -a \! -f %{_sysconfdir}/sysconfig/hddtemp ; then
    . %{_sysconfdir}/default/hddtemp
    optarg_parse $hddtemp_opts
    EXPR=
    if $OPTARG_INTERVAL ; then
    echo "HDDTEMP_CHECK_INTERVAL=\"$OPTVAL_INTERVAL\"" >>%{_sysconfdir}/sysconfig/hddtemp
    EXPR="s/=\"1800\"/=\"$OPTVAL_INTERVAL\"/;"
    fi
    if $OPTARG_LOGFACILITY ; then
    echo "HDDTEMP_LOG_FACILITY=\"$OPTVAL_LOGFACILITY\"" >>%{_sysconfdir}/sysconfig/hddtemp
    EXPR="${EXPR}s/=\"daemon\"/=\"$OPTVAL_LOGFACILITY\"/;"
    fi
    sed "$EXPR" </var/adm/fillup-templates/sysconfig.hddtemp >%{_sysconfdir}/sysconfig/hddtemp
    rm %{_sysconfdir}/default/hddtemp
fi
#END hddtemp_opts_migrate
# Turn hddtemp on by default.
%{fillup_and_insserv -Y hddtemp}
# Older SuSE versions (<=10.2) don't do restart on update. Do it now.
if test -f var/adm/hddtemp_needs_restart ; then
rm var/adm/hddtemp_needs_restart
%{restart_on_update hddtemp}
fi

%preun
if [ "$1" = "0" ]; then # remove
    chkconfig --del %{name}
fi
%{stop_on_removal hddtemp}

%postun
%{restart_on_update hddtemp}
%{insserv_cleanup}

%files -f "%{name}.lang"
%defattr(-,root,root)
%doc COPYING README TODO contribs
%config(noreplace) %{_datadir}/misc/hddtemp.db
%config(noreplace) %{_sysconfdir}/init.d/%{name}
/var/adm/fillup-templates/sysconfig.%{name}
/etc/hddtemp.db
%doc %{_mandir}/man8/hddtemp.8*
%{_sbindir}/hddtemp
%{_sbindir}/rchddtemp

%changelog
* Mon Apr 23 2012 pascal.bleser@opensuse.org
- fixes to build on openSUSE >= 12.1 on 32bit, needs passing -D_GNU_SOURCE to
  compiler
- modernize spec file a little towards nowadays factory compliance
* Wed Sep 16 2009 Manfred.Tremmel@iiv.de
- fixes in post/pre scripts
* Tue Sep  8 2009 Manfred.Tremmel@iiv.de
- cleanups where rpmlint wasn't so happy
* Thu Mar 29 2007 Manfred.Tremmel@iiv.de
- added patches from devil_at_decagon.de and debian
* Wed May  3 2006 Manfred.Tremmel@iiv.de
- Update to 0.3beta15
* Wed Sep 21 2005 Manfred.Tremmel@iiv.de
- Update to 0.3beta14
* Sat Apr  2 2005 Manfred.Tremmel@iiv.de
- readded a script from Mr.Bool in post section
* Wed Mar 23 2005 Manfred.Tremmel@iiv.de
- Update to 0.3beta13
* Thu Mar 17 2005 Manfred.Tremmel@iiv.de
- readded chmod +s, sorry was missing
* Wed Mar 16 2005 Manfred.Tremmel@iiv.de
- Update to 0.3beta12
* Sun Dec  7 2003 Manfred.Tremmel@iiv.de
- Update to 0.3beta9
* Sat Aug 16 2003 Manfred.Tremmel@iiv.de
- Update to 0.3beta8
* Sat Jun 21 2003 Manfred.Tremmel@iiv.de
- Update to 0.3beta7
* Sat Apr 19 2003 Manfred.Tremmel@iiv.de
- Update to 0.3beta6
* Mon Mar 24 2003 Manfred.Tremmel@iiv.de
- Update to 0.3beta5
  Thu Mar 13 00:00:00 UTC 2003 - Mr.Bool <mr.bool at rambler.ru>
- Update to 0.3beta4
* Sat Jan 25 2003 Manfred.Tremmel@iiv.de
- Update to 0.3beta3
* Sat Jan  4 2003 Manfred.Tremmel@iiv.de
- Update to 0.3beta2
  Wed Dec  4 00:00:00 UTC 2002 - Mr.Bool <mr.bool at rambler.ru>
- some cleanups : hddtemp.sysconfig , hddtemp.spec
* Sun Dec  1 2002 Manfred.Tremmel@iiv.de
- Update to 0.3beta1
  Sat Oct 12 00:00:00 UTC 2002 - Mr.Bool <mr.bool at rambler.ru> 0.3-0.alpha.3cr_SuSE8.x
- Rebuild for SuSE 8.0.
- Added /etc/bash.bashrc.local creation
- New init script (LSB compatible?)
- Configuration has more parameters
- Suid root again
- Spec file changed
- Default drive is /dev/hda
  Sun Oct  6 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.3-0.alpha.3cr
- Rebuild for Red Hat 8.0.
  Tue Aug 13 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.3-0.alpha.2cr
- Patched db.
  Sat Aug  3 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.3-0.alpha.1cr
- Update to 0.3 alpha.
- No more suid root.
  Tue Jul 30 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.2-4cr
- hddtemp.db version 19.
  Tue Jul 23 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.2-3cr
- hddtemp.db version 18.
  Wed Jul 10 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.2-2cr
- hddtemp.db version 17.
  Tue Jul  2 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.2-1cr
- Updated hddtemp.db.
  Thu Jun  6 00:00:00 UTC 2002 - Ville Skytt <ville.skytta at iki.fi> 0.2-0.1
- Initial build.
